@@ -464,6 +464,55 @@ get_menu_model (GeditApp   *app,
 	return menu ? G_MENU_MODEL (g_object_ref_sink (menu)) : NULL;
 }
 
+static void
+add_accelerator (GeditApp    *app,
+                 const gchar *action_name,
+                 const gchar *accel)
+{
+	const gchar *vaccels[] = {
+		accel,
+		NULL
+	};
+
+	gtk_application_set_accels_for_action (GTK_APPLICATION (app), action_name, vaccels);
+}
+
+static void
+load_css_from_resource (const gchar *filename,
+                        gboolean     required)
+{
+	GError *error = NULL;
+	GFile *css_file;
+	GtkCssProvider *provider;
+	gchar *resource_name;
+
+	resource_name = g_strdup_printf ("resource:///org/gnome/gedit/css/%s", filename);
+	css_file = g_file_new_for_uri (resource_name);
+	g_free (resource_name);
+
+	if (!required && !g_file_query_exists (css_file, NULL))
+	{
+		return;
+	}
+
+	provider = gtk_css_provider_new ();
+
+	if (gtk_css_provider_load_from_file (provider, css_file, &error))
+	{
+		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+		                                           GTK_STYLE_PROVIDER (provider),
+		                                           GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		g_object_unref (provider);
+	}
+	else
+	{
+		g_warning ("Could not load css provider: %s", error->message);
+		g_error_free (error);
+	}
+
+	g_object_unref (css_file);
+}
+
 static void
 gedit_app_startup (GApplication *application)
 {
@@ -471,9 +520,6 @@ gedit_app_startup (GApplication *application)
 	GtkSourceStyleSchemeManager *manager;
 	const gchar *dir;
 	gchar *icon_dir;
-	GError *error = NULL;
-	GFile *css_file;
-	GtkCssProvider *provider;
 
 	G_APPLICATION_CLASS (gedit_app_parent_class)->startup (application);
 
@@ -509,89 +555,57 @@ gedit_app_startup (GApplication *application)
 	                                 app);
 
 	/* menus */
-	app->priv->window_menu = get_menu_model (app, "gear-menu");
+	app->priv->window_menu = gtk_application_get_menubar (GTK_APPLICATION (app));
+
+	if (app->priv->window_menu == NULL)
+	{
+		app->priv->window_menu = get_menu_model (app, "gear-menu");
+	}
+	else
+	{
+		g_object_ref (app->priv->window_menu);
+	}
+
 	app->priv->notebook_menu = get_menu_model (app, "notebook-menu");
 	app->priv->tab_width_menu = get_menu_model (app, "tab-width-menu");
 	app->priv->line_col_menu = get_menu_model (app, "line-col-menu");
 
 	/* Accelerators */
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-					 "<Primary>N", "app.new-window", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>Q", "app.quit", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "F1", "app.help", NULL);
+	add_accelerator (app, "app.new-window", "<Primary>N");
+	add_accelerator (app, "app.quit", "<Primary>Q");
+	add_accelerator (app, "app.help", "F1");
 
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>O", "win.open", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>S", "win.save", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>S", "win.save-as", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>L", "win.save-all", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>T", "win.new-tab", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>T", "win.reopen-closed-tab", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>W", "win.close", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>W", "win.close-all", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>P", "win.print", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>F", "win.find", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>G", "win.find-next", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>G", "win.find-prev", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>H", "win.replace", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift>K", "win.clear-highlight", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>I", "win.goto-line", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "F9", "win.side-panel", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary>F9", "win.bottom-panel", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "F11", "win.fullscreen", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Alt>N", "win.new-tab-group", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift><Alt>Page_Up",
-	                                 "win.previous-tab-group", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Shift><Alt>Page_Down",
-	                                 "win.next-tab-group", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Alt>Page_Up",
-	                                 "win.previous-document", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (application),
-	                                 "<Primary><Alt>Page_Down",
-	                                 "win.next-document", NULL);
+	add_accelerator (app, "win.gear-menu", "F10");
+	add_accelerator (app, "win.open", "<Primary>O");
+	add_accelerator (app, "win.save", "<Primary>S");
+	add_accelerator (app, "win.save-as", "<Primary><Shift>S");
+	add_accelerator (app, "win.save-all", "<Primary><Shift>L");
+	add_accelerator (app, "win.new-tab", "<Primary>T");
+	add_accelerator (app, "win.reopen-closed-tab", "<Primary><Shift>T");
+	add_accelerator (app, "win.close", "<Primary>W");
+	add_accelerator (app, "win.close-all", "<Primary><Shift>W");
+	add_accelerator (app, "win.print", "<Primary>P");
+	add_accelerator (app, "win.find", "<Primary>F");
+	add_accelerator (app, "win.find-next", "<Primary>G");
+	add_accelerator (app, "win.find-prev", "<Primary><Shift>G");
+	add_accelerator (app, "win.replace", "<Primary>H");
+	add_accelerator (app, "win.clear-highlight", "<Primary><Shift>K");
+	add_accelerator (app, "win.goto-line", "<Primary>I");
+	add_accelerator (app, "win.focus-active-view", "Escape");
+	add_accelerator (app, "win.side-panel", "F9");
+	add_accelerator (app, "win.bottom-panel", "<Primary>F9");
+	add_accelerator (app, "win.fullscreen", "F11");
+	add_accelerator (app, "win.new-tab-group", "<Primary><Alt>N");
+	add_accelerator (app, "win.previous-tab-group", "<Primary><Shift><Alt>Page_Up");
+	add_accelerator (app, "win.next-tab-group", "<Primary><Shift><Alt>Page_Down");
+	add_accelerator (app, "win.previous-document", "<Primary><Alt>Page_Up");
+	add_accelerator (app, "win.next-document", "<Primary><Alt>Page_Down");
 
 	load_accels ();
 
 	/* Load custom css */
-	error = NULL;
-	css_file = g_file_new_for_uri ("resource:///org/gnome/gedit/css/gedit-style.css");
-	provider = gtk_css_provider_new ();
-	if (gtk_css_provider_load_from_file (provider, css_file, &error))
-	{
-		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-		                                           GTK_STYLE_PROVIDER (provider),
-		                                           GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-		g_object_unref (provider);
-	}
-	else
-	{
-		g_warning ("Could not load css provider: %s", error->message);
-		g_error_free (error);
-	}
-	g_object_unref (css_file);
+	load_css_from_resource ("gedit-style.css", TRUE);
+	load_css_from_resource ("gedit-style-os.css", FALSE);
 
 	/*
 	 * We use the default gtksourceview style scheme manager so that plugins
@@ -1172,13 +1186,17 @@ gedit_app_shutdown (GApplication *app)
 	save_page_setup (GEDIT_APP (app));
 	save_print_settings (GEDIT_APP (app));
 
+	/* GTK+ can still hold references to some gedit objects, for example
+	 * GeditDocument for the clipboard. So the metadata-manager should be
+	 * shutdown after.
+	 */
+	G_APPLICATION_CLASS (gedit_app_parent_class)->shutdown (app);
+
 #ifndef ENABLE_GVFS_METADATA
 	gedit_metadata_manager_shutdown ();
 #endif
 
 	gedit_dirs_shutdown ();
-
-	G_APPLICATION_CLASS (gedit_app_parent_class)->shutdown (app);
 }
 
 static gboolean
@@ -1608,8 +1626,7 @@ find_extension_point_section (GMenuModel  *model,
 		{
 			section = g_menu_model_get_item_link (model, i, G_MENU_LINK_SECTION);
 		}
-		/* unamed sections are to be checked recursively */
-		else if (id == NULL)
+		else
 		{
 			GMenuModel *subsection;
 			GMenuModel *submenu;
