@@ -379,17 +379,26 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 	if (response_id != GTK_RESPONSE_OK)
 	{
-		gtk_widget_destroy (GTK_WIDGET (dialog));
+		gedit_file_chooser_dialog_destroy (dialog);
 
 		return;
 	}
 
-	files = gtk_file_chooser_get_files (GTK_FILE_CHOOSER (dialog));
+	files = gedit_file_chooser_dialog_get_files (dialog);
 	g_return_if_fail (files != NULL);
 
 	encoding = gedit_file_chooser_dialog_get_encoding (dialog);
 
-	gtk_widget_destroy (GTK_WIDGET (dialog));
+	gedit_file_chooser_dialog_destroy (dialog);
+
+	if (window == NULL)
+	{
+		window = gedit_app_create_window (GEDIT_APP (g_application_get_default ()),
+		                                  NULL);
+
+		gtk_widget_show (GTK_WIDGET (window));
+		gtk_window_present (GTK_WINDOW (window));
+	}
 
 	/* Remember the folder we navigated to */
 	 _gedit_window_set_default_location (window, files->data);
@@ -409,71 +418,80 @@ _gedit_cmd_file_open (GSimpleAction *action,
                       GVariant      *parameter,
                       gpointer       user_data)
 {
-	GeditWindow *window = GEDIT_WINDOW (user_data);
-	GtkWidget *open_dialog;
-	gpointer data;
-	GeditDocument *doc;
-	GFile *default_path = NULL;
+	GeditWindow *window = NULL;
+	GeditFileChooserDialog *open_dialog;
+
+	if (GEDIT_IS_WINDOW (user_data))
+	{
+		window = GEDIT_WINDOW (user_data);
+	}
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	data = g_object_get_data (G_OBJECT (window), GEDIT_OPEN_DIALOG_KEY);
-
-	if (data != NULL)
+	if (window != NULL)
 	{
-		g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (data));
+		gpointer data;
 
-		gtk_window_present (GTK_WINDOW (data));
+		data = g_object_get_data (G_OBJECT (window), GEDIT_OPEN_DIALOG_KEY);
 
-		return;
+		if (data != NULL)
+		{
+			g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (data));
+
+			gtk_window_present (GTK_WINDOW (data));
+
+			return;
+		}
+
+		gtk_widget_hide (GTK_WIDGET (window->priv->open_document_popover));
+		gtk_widget_hide (GTK_WIDGET (window->priv->fullscreen_open_document_popover));
 	}
 
-	gtk_widget_hide (GTK_WIDGET (window->priv->open_document_popover));
-	gtk_widget_hide (GTK_WIDGET (window->priv->fullscreen_open_document_popover));
-
 	/* Translators: "Open" is the title of the file chooser window */
-	open_dialog = gedit_file_chooser_dialog_new (_("Open"),
-						     GTK_WINDOW (window),
-						     GTK_FILE_CHOOSER_ACTION_OPEN,
-						     NULL,
-						     _("_Cancel"), GTK_RESPONSE_CANCEL,
-						     _("_Open"), GTK_RESPONSE_OK,
-						     NULL);
+	open_dialog = gedit_file_chooser_dialog_create (_("Open"),
+							window ? GTK_WINDOW (window) : NULL,
+							GEDIT_FILE_CHOOSER_OPEN |
+							GEDIT_FILE_CHOOSER_ENABLE_ENCODING |
+							GEDIT_FILE_CHOOSER_ENABLE_DEFAULT_FILTERS,
+							NULL,
+							_("_Cancel"), GTK_RESPONSE_CANCEL,
+							_("_Open"), GTK_RESPONSE_OK);
 
-	g_object_set_data (G_OBJECT (window),
-			   GEDIT_OPEN_DIALOG_KEY,
-			   open_dialog);
-
-	g_object_weak_ref (G_OBJECT (open_dialog),
-			   (GWeakNotify) open_dialog_destroyed,
-			   window);
-
-	/* Set the curret folder uri */
-	doc = gedit_window_get_active_document (window);
-	if (doc != NULL)
+	if (window != NULL)
 	{
-		GtkSourceFile *file = gedit_document_get_file (doc);
-		GFile *location = gtk_source_file_get_location (file);
+		GeditDocument *doc;
+		GFile *default_path = NULL;
 
-		if (location != NULL)
+		g_object_set_data (G_OBJECT (window),
+				   GEDIT_OPEN_DIALOG_KEY,
+				   open_dialog);
+
+		g_object_weak_ref (G_OBJECT (open_dialog),
+				   (GWeakNotify) open_dialog_destroyed,
+				   window);
+
+		/* Set the current folder uri */
+		doc = gedit_window_get_active_document (window);
+
+		if (doc != NULL)
 		{
-			default_path = g_file_get_parent (location);
+			GtkSourceFile *file = gedit_document_get_file (doc);
+			GFile *location = gtk_source_file_get_location (file);
+
+			if (location != NULL)
+			{
+				default_path = g_file_get_parent (location);
+			}
 		}
-	}
 
-	if (default_path == NULL)
-		default_path = _gedit_window_get_default_location (window);
+		if (default_path == NULL)
+			default_path = _gedit_window_get_default_location (window);
 
-	if (default_path != NULL)
-	{
-		gchar *uri;
-
-		uri = g_file_get_uri (default_path);
-		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (open_dialog),
-							 uri);
-
-		g_free (uri);
-		g_object_unref (default_path);
+		if (default_path != NULL)
+		{
+			gedit_file_chooser_dialog_set_current_folder (open_dialog, default_path);
+			g_object_unref (default_path);
+		}
 	}
 
 	g_signal_connect (open_dialog,
@@ -481,7 +499,7 @@ _gedit_cmd_file_open (GSimpleAction *action,
 			  G_CALLBACK (open_dialog_response_cb),
 			  window);
 
-	gtk_widget_show (open_dialog);
+	gedit_file_chooser_dialog_show (open_dialog);
 }
 
 void
@@ -591,7 +609,6 @@ change_compression (GtkWindow *parent,
 	gchar *parse_name;
 	gchar *name_for_display;
 	const gchar *primary_message;
-	const gchar *secondary_message;
 	const gchar *button_label;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -608,16 +625,10 @@ change_compression (GtkWindow *parent,
 	if (compressed)
 	{
 		primary_message = _("Save the file using compression?");
-		secondary_message = _("The file \"%s\" was previously saved as plain "
-		                      "text and will now be saved using compression.");
-		button_label = _("_Save Using Compression");
 	}
 	else
 	{
 		primary_message = _("Save the file as plain text?");
-		secondary_message = _("The file \"%s\" was previously saved "
-		                      "using compression and will now be saved as plain text.");
-		button_label = _("_Save As Plain Text");
 	}
 
 	dialog = gtk_message_dialog_new (parent,
@@ -627,9 +638,24 @@ change_compression (GtkWindow *parent,
 					 "%s",
 					 primary_message);
 
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  secondary_message,
-						  name_for_display);
+	if (compressed)
+	{
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("The file \"%s\" was previously saved as plain "
+							    "text and will now be saved using compression."),
+							  name_for_display);
+
+		button_label = _("_Save Using Compression");
+	}
+	else
+	{
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("The file \"%s\" was previously saved "
+							    "using compression and will now be saved as plain text."),
+							  name_for_display);
+		button_label = _("_Save As Plain Text");
+	}
+
 
 	g_free (name_for_display);
 
@@ -684,7 +710,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 	if (response_id != GTK_RESPONSE_OK)
 	{
-		gtk_widget_destroy (GTK_WIDGET (dialog));
+		gedit_file_chooser_dialog_destroy (dialog);
 
 		goto save_next_tab;
 	}
@@ -703,7 +729,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		doc = gedit_tab_get_document (tab);
 		file = gedit_document_get_file (doc);
 
-		location = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
+		location = gedit_file_chooser_dialog_get_file (dialog);
 		g_return_if_fail (location != NULL);
 
 		compression_type = get_compression_type_from_file (location);
@@ -716,7 +742,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 			                         location,
 			                         compression_type != GTK_SOURCE_COMPRESSION_TYPE_NONE))
 			{
-				gtk_widget_destroy (GTK_WIDGET (dialog));
+				gedit_file_chooser_dialog_destroy (dialog);
 				g_object_unref (location);
 
 				goto save_next_tab;
@@ -726,7 +752,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		encoding = gedit_file_chooser_dialog_get_encoding (dialog);
 		newline_type = gedit_file_chooser_dialog_get_newline_type (dialog);
 
-		gtk_widget_destroy (GTK_WIDGET (dialog));
+		gedit_file_chooser_dialog_destroy (dialog);
 
 		doc = gedit_tab_get_document (tab);
 		g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
@@ -792,25 +818,30 @@ save_next_tab:
 }
 
 static GtkFileChooserConfirmation
-confirm_overwrite_callback (GtkFileChooser *dialog,
-			    gpointer        data)
+confirm_overwrite_callback (GeditFileChooserDialog *dialog,
+			    gpointer                data)
 {
-	gchar *uri;
 	GFile *file;
 	GtkFileChooserConfirmation res;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	uri = gtk_file_chooser_get_uri (dialog);
-	file = g_file_new_for_uri (uri);
-	g_free (uri);
+	file = gedit_file_chooser_dialog_get_file (dialog);
 
 	if (is_read_only (file))
 	{
-		if (replace_read_only_file (GTK_WINDOW (dialog), file))
+		GtkWindow *win;
+
+		win = gedit_file_chooser_dialog_get_window (dialog);
+
+		if (replace_read_only_file (win, file))
+		{
 			res = GTK_FILE_CHOOSER_CONFIRMATION_ACCEPT_FILENAME;
+		}
 		else
+		{
 			res = GTK_FILE_CHOOSER_CONFIRMATION_SELECT_AGAIN;
+		}
 	}
 	else
 	{
@@ -827,29 +858,32 @@ void
 _gedit_cmd_file_save_as_tab (GeditTab    *tab,
                              GeditWindow *window)
 {
-	GtkWidget *save_dialog;
+	GeditFileChooserDialog *save_dialog;
 	GtkWindowGroup *wg;
 	GeditDocument *doc;
 	GtkSourceFile *file;
 	GFile *location;
 	const GtkSourceEncoding *encoding;
 	GtkSourceNewlineType newline_type;
+	GtkWindow *win;
 
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 	g_return_if_fail (GEDIT_IS_WINDOW (window));
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	save_dialog = gedit_file_chooser_dialog_new (_("Save As"),
-						     GTK_WINDOW (window),
-						     GTK_FILE_CHOOSER_ACTION_SAVE,
-						     NULL,
-						     _("_Cancel"), GTK_RESPONSE_CANCEL,
-						     _("_Save"), GTK_RESPONSE_OK,
-						     NULL);
+	save_dialog = gedit_file_chooser_dialog_create (_("Save As"),
+							GTK_WINDOW (window),
+							GEDIT_FILE_CHOOSER_SAVE |
+							GEDIT_FILE_CHOOSER_ENABLE_ENCODING |
+							GEDIT_FILE_CHOOSER_ENABLE_LINE_ENDING |
+							GEDIT_FILE_CHOOSER_ENABLE_DEFAULT_FILTERS,
+							NULL,
+							_("_Cancel"), GTK_RESPONSE_CANCEL,
+							_("_Save"), GTK_RESPONSE_OK);
+
+	gedit_file_chooser_dialog_set_do_overwrite_confirmation (save_dialog, TRUE);
 
-	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (save_dialog),
-							TRUE);
 	g_signal_connect (save_dialog,
 			  "confirm-overwrite",
 			  G_CALLBACK (confirm_overwrite_callback),
@@ -857,10 +891,15 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 
 	wg = gedit_window_get_group (window);
 
-	gtk_window_group_add_window (wg, GTK_WINDOW (save_dialog));
+	win = gedit_file_chooser_dialog_get_window (save_dialog);
+
+	if (win != NULL)
+	{
+		gtk_window_group_add_window (wg, win);
+	}
 
 	/* Save As dialog is modal to its main window */
-	gtk_window_set_modal (GTK_WINDOW (save_dialog), TRUE);
+	gedit_file_chooser_dialog_set_modal (save_dialog, TRUE);
 
 	/* Set the suggested file name */
 	doc = gedit_tab_get_document (tab);
@@ -869,9 +908,7 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 
 	if (location != NULL)
 	{
-		gtk_file_chooser_set_file (GTK_FILE_CHOOSER (save_dialog),
-					   location,
-					   NULL);
+		gedit_file_chooser_dialog_set_file (save_dialog, location);
 	}
 	else
 	{
@@ -883,18 +920,14 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 
 		if (default_path != NULL)
 		{
-			gchar *uri;
+			gedit_file_chooser_dialog_set_current_folder (save_dialog,
+								      default_path);
 
-			uri = g_file_get_uri (default_path);
-			gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (save_dialog),
-								 uri);
-
-			g_free (uri);
 			g_object_unref (default_path);
 		}
 
-		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (save_dialog),
-						   docname);
+		gedit_file_chooser_dialog_set_current_name (save_dialog,
+							    docname);
 
 		g_free (docname);
 	}
@@ -924,7 +957,7 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 			  G_CALLBACK (save_dialog_response_cb),
 			  window);
 
-	gtk_widget_show (save_dialog);
+	gedit_file_chooser_dialog_show (save_dialog);
 }
 
 void
@@ -1353,6 +1386,34 @@ _gedit_cmd_file_revert (GSimpleAction *action,
 	gtk_widget_show (dialog);
 }
 
+static void
+quit_if_needed (GeditWindow *window)
+{
+	gboolean is_quitting;
+	gboolean is_quitting_all;
+
+	is_quitting = GPOINTER_TO_BOOLEAN (g_object_get_data (G_OBJECT (window),
+							      GEDIT_IS_QUITTING));
+
+	is_quitting_all = GPOINTER_TO_BOOLEAN (g_object_get_data (G_OBJECT (window),
+							          GEDIT_IS_QUITTING_ALL));
+
+	if (is_quitting)
+		gtk_widget_destroy (GTK_WIDGET (window));
+
+	if (is_quitting_all)
+	{
+		GtkApplication *app;
+
+		app = GTK_APPLICATION (g_application_get_default ());
+
+		if (gtk_application_get_windows (app) == NULL)
+		{
+			g_application_quit (G_APPLICATION (app));
+		}
+	}
+}
+
 /* Close tab */
 static gboolean
 really_close_tab (GeditTab *tab)
@@ -1374,13 +1435,7 @@ really_close_tab (GeditTab *tab)
 
 	if (gedit_window_get_active_tab (window) == NULL)
 	{
-		gboolean is_quitting;
-
-		is_quitting = GPOINTER_TO_BOOLEAN (g_object_get_data (G_OBJECT (window),
-								      GEDIT_IS_QUITTING));
-
-		if (is_quitting)
-			gtk_widget_destroy (GTK_WIDGET (window));
+		quit_if_needed (window);
 	}
 
 	return FALSE;
@@ -1628,20 +1683,12 @@ save_and_close_document (const GList  *docs,
 static void
 close_all_tabs (GeditWindow *window)
 {
-	gboolean is_quitting;
-
 	gedit_debug (DEBUG_COMMANDS);
 
 	/* There is no document to save -> close all tabs */
 	gedit_window_close_all_tabs (window);
 
-	is_quitting = GPOINTER_TO_BOOLEAN (g_object_get_data (G_OBJECT (window),
-							      GEDIT_IS_QUITTING));
-
-	if (is_quitting)
-		gtk_widget_destroy (GTK_WIDGET (window));
-
-	return;
+	quit_if_needed (window);
 }
 
 static void
@@ -1755,11 +1802,9 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 			                   GEDIT_IS_QUITTING,
 			                   GBOOLEAN_TO_POINTER (FALSE));
 
-#ifdef OS_OSX
 			g_object_set_data (G_OBJECT (window),
 			                   GEDIT_IS_QUITTING_ALL,
-			                   GINT_TO_POINTER (FALSE));
-#endif
+			                   GBOOLEAN_TO_POINTER (FALSE));
 			break;
 	}
 
@@ -1821,7 +1866,7 @@ _gedit_cmd_file_close_tab (GeditTab    *tab,
 
 	g_object_set_data (G_OBJECT (window),
 	                   GEDIT_IS_QUITTING_ALL,
-	                   GINT_TO_POINTER (FALSE));
+	                   GBOOLEAN_TO_POINTER (FALSE));
 
 	if (tab_can_close (tab, GTK_WINDOW (window)))
 	{
@@ -1843,10 +1888,7 @@ _gedit_cmd_file_close (GSimpleAction *action,
 
 	if (active_tab == NULL)
 	{
-#ifdef OS_OSX
-		/* Close the window on OS X */
 		gtk_widget_destroy (GTK_WIDGET (window));
-#endif
 		return;
 	}
 
@@ -1920,7 +1962,7 @@ _gedit_cmd_file_close_notebook (GeditWindow   *window,
 
 	g_object_set_data (G_OBJECT (window), GEDIT_IS_CLOSING_ALL, GBOOLEAN_TO_POINTER (FALSE));
 	g_object_set_data (G_OBJECT (window), GEDIT_IS_QUITTING, GBOOLEAN_TO_POINTER (FALSE));
-	g_object_set_data (G_OBJECT (window), GEDIT_IS_QUITTING_ALL, GINT_TO_POINTER (FALSE));
+	g_object_set_data (G_OBJECT (window), GEDIT_IS_QUITTING_ALL, GBOOLEAN_TO_POINTER (FALSE));
 
 	g_object_set_data (G_OBJECT (window), GEDIT_NOTEBOOK_TO_CLOSE, notebook);
 
@@ -1972,11 +2014,7 @@ file_close_all (GeditWindow *window,
 	{
 		/* There is no document to save -> close all tabs */
 		gedit_window_close_all_tabs (window);
-
-		if (is_quitting)
-		{
-			gtk_widget_destroy (GTK_WIDGET (window));
-		}
+		quit_if_needed (window);
 	}
 }
 
@@ -2002,8 +2040,16 @@ quit_all (void)
 {
 	GList *windows;
 	GList *l;
+	GApplication *app;
 
-	windows = gedit_app_get_main_windows (GEDIT_APP (g_application_get_default ()));
+	app = g_application_get_default ();
+	windows = gedit_app_get_main_windows (GEDIT_APP (app));
+
+	if (windows == NULL)
+	{
+		g_application_quit (app);
+		return;
+	}
 
 	for (l = windows; l != NULL; l = g_list_next (l))
 	{
@@ -2011,7 +2057,7 @@ quit_all (void)
 
 		g_object_set_data (G_OBJECT (window),
 		                   GEDIT_IS_QUITTING_ALL,
-		                   GINT_TO_POINTER (TRUE));
+		                   GBOOLEAN_TO_POINTER (TRUE));
 
 		if (!(gedit_window_get_state (window) &
 		      (GEDIT_WINDOW_STATE_SAVING | GEDIT_WINDOW_STATE_PRINTING)))
