@@ -32,6 +32,24 @@
 #include "gedit-highlight-mode-dialog.h"
 #include "gedit-highlight-mode-selector.h"
 
+void
+_gedit_cmd_view_focus_active (GSimpleAction *action,
+                              GVariant      *state,
+                              gpointer       user_data)
+{
+	GeditView *active_view;
+	GeditWindow *window = GEDIT_WINDOW (user_data);
+
+	gedit_debug (DEBUG_COMMANDS);
+
+	active_view = gedit_window_get_active_view (window);
+
+	if (active_view)
+	{
+		gtk_widget_grab_focus (GTK_WIDGET (active_view));
+	}
+}
+
 void
 _gedit_cmd_view_toggle_side_panel (GSimpleAction *action,
                                    GVariant      *state,
@@ -97,8 +115,6 @@ _gedit_cmd_view_toggle_fullscreen_mode (GSimpleAction *action,
 	{
 		_gedit_window_unfullscreen (window);
 	}
-
-	g_simple_action_set_state (action, state);
 }
 
 void
@@ -106,16 +122,7 @@ _gedit_cmd_view_leave_fullscreen_mode (GSimpleAction *action,
                                        GVariant      *parameter,
                                        gpointer       user_data)
 {
-	GeditWindow *window = GEDIT_WINDOW (user_data);
-	GAction *fullscreen_action;
-
-	_gedit_window_unfullscreen (window);
-
-	fullscreen_action = g_action_map_lookup_action (G_ACTION_MAP (window),
-	                                                "fullscreen");
-
-	g_simple_action_set_state (G_SIMPLE_ACTION (fullscreen_action),
-	                           g_variant_new_boolean (FALSE));
+	_gedit_window_unfullscreen (GEDIT_WINDOW (user_data));
 }
 
 static void
