@@ -19,7 +19,6 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <time.h>
 #include <stdlib.h>
 #include <libxml/xmlreader.h>
 #include "gedit-debug.h"
@@ -39,7 +38,7 @@ typedef struct _Item Item;
 
 struct _Item
 {
-	time_t	 	 atime; /* time of last access */
+	gint64	 	 atime; /* time of last access in seconds since January 1, 1970 UTC */
 
 	GHashTable	*values;
 };
@@ -182,7 +181,7 @@ parseItem (xmlDocPtr doc, xmlNodePtr cur)
 
 	item = g_new0 (Item, 1);
 
-	item->atime = g_ascii_strtoull ((char *)atime, NULL, 0);
+	item->atime = g_ascii_strtoll ((char *)atime, NULL, 0);
 
 	item->values = g_hash_table_new_full (g_str_hash,
 					      g_str_equal,
@@ -331,7 +330,7 @@ gedit_metadata_manager_get (GFile       *location,
 	if (item == NULL)
 		return NULL;
 
-	item->atime = time (NULL);
+	item->atime = g_get_real_time () / 1000;
 
 	if (item->values == NULL)
 		return NULL;
@@ -409,7 +408,7 @@ gedit_metadata_manager_set (GFile       *location,
 				     key);
 	}
 
-	item->atime = time (NULL);
+	item->atime = g_get_real_time () / 1000;
 
 	g_free (uri);
 
@@ -471,7 +470,7 @@ save_item (const gchar *key, const gpointer *data, xmlNodePtr parent)
 	gedit_debug_message (DEBUG_METADATA, "uri: %s", key);
 #endif
 
-	atime = g_strdup_printf ("%ld", item->atime);
+	atime = g_strdup_printf ("%" G_GINT64_FORMAT, item->atime);
 	xmlSetProp (xml_node, (const xmlChar *)"atime", (const xmlChar *)atime);
 
 #ifdef GEDIT_METADATA_VERBOSE_DEBUG
