@@ -26,18 +26,11 @@
 #endif
 
 #include <string.h>
-
 #include <gtksourceview/gtksource.h>
-
-#include "gedit-settings.h"
 #include "gedit-app.h"
-#include "gedit-debug.h"
 #include "gedit-view.h"
 #include "gedit-window.h"
-#include "gedit-plugins-engine.h"
-#include "gedit-dirs.h"
-#include "gedit-utils.h"
-#include "gedit-window-private.h"
+#include "gedit-settings.h"
 
 #define GEDIT_SETTINGS_LOCKDOWN_COMMAND_LINE "disable-command-line"
 #define GEDIT_SETTINGS_LOCKDOWN_PRINTING "disable-printing"
