@@ -21,7 +21,7 @@
 #ifndef __GEDIT_TAB_H__
 #define __GEDIT_TAB_H__
 
-#include <gtk/gtk.h>
+#include <gtksourceview/gtksource.h>
 #include <gedit/gedit-view.h>
 #include <gedit/gedit-document.h>
 
@@ -107,40 +107,41 @@ GtkWidget 	*_gedit_tab_new 		(void);
 
 /* Whether create is TRUE, creates a new empty document if location does
    not refer to an existing location */
-GtkWidget	*_gedit_tab_new_from_location	(GFile               *location,
-						 const GeditEncoding *encoding,
-						 gint                 line_pos,
-						 gint                 column_pos,
-						 gboolean             create);
+GtkWidget	*_gedit_tab_new_from_location	(GFile                   *location,
+						 const GtkSourceEncoding *encoding,
+						 gint                     line_pos,
+						 gint                     column_pos,
+						 gboolean                 create);
 
-GtkWidget	*_gedit_tab_new_from_stream	(GInputStream        *stream,
-						 const GeditEncoding *encoding,
-						 gint                 line_pos,
-						 gint                 column_pos);
+GtkWidget	*_gedit_tab_new_from_stream	(GInputStream            *stream,
+						 const GtkSourceEncoding *encoding,
+						 gint                     line_pos,
+						 gint                     column_pos);
 
 gchar 		*_gedit_tab_get_name		(GeditTab            *tab);
 gchar 		*_gedit_tab_get_tooltip		(GeditTab            *tab);
 GdkPixbuf 	*_gedit_tab_get_icon		(GeditTab            *tab);
-void		 _gedit_tab_load		(GeditTab            *tab,
-						 GFile               *location,
-						 const GeditEncoding *encoding,
-						 gint                 line_pos,
-						 gint                 column_pos,
-						 gboolean             create);
+void		 _gedit_tab_load		(GeditTab                *tab,
+						 GFile                   *location,
+						 const GtkSourceEncoding *encoding,
+						 gint                     line_pos,
+						 gint                     column_pos,
+						 gboolean                 create);
 
-void		 _gedit_tab_load_stream		(GeditTab            *tab,
-						 GInputStream        *location,
-						 const GeditEncoding *encoding,
-						 gint                 line_pos,
-						 gint                 column_pos);
+void		 _gedit_tab_load_stream		(GeditTab                *tab,
+						 GInputStream            *location,
+						 const GtkSourceEncoding *encoding,
+						 gint                     line_pos,
+						 gint                     column_pos);
 
 void		 _gedit_tab_revert		(GeditTab            *tab);
 void		 _gedit_tab_save		(GeditTab            *tab);
-void		 _gedit_tab_save_as		(GeditTab            *tab,
-						 GFile               *location,
-						 const GeditEncoding *encoding,
-						 GeditDocumentNewlineType newline_type,
-						 GeditDocumentCompressionType compression_type);
+
+void		 _gedit_tab_save_as		(GeditTab                *tab,
+						 GFile                   *location,
+						 const GtkSourceEncoding *encoding,
+						 GtkSourceNewlineType     newline_type,
+						 GtkSourceCompressionType compression_type);
 
 void		 _gedit_tab_print		(GeditTab            *tab);
 void		 _gedit_tab_print_preview	(GeditTab            *tab);
