@@ -15,8 +15,7 @@
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -125,40 +124,4 @@ gedit_window_activatable_update_state (GeditWindowActivatable *activatable)
 	}
 }
 
-GeditMenuExtension *
-gedit_window_activatable_extend_gear_menu (GeditWindowActivatable *activatable,
-                                           const gchar            *extension_point)
-{
-	GeditMenuExtension *menu = NULL;
-	GeditWindow *window;
-	GMenuModel *model;
-	gint i, n_items;
-
-	g_return_val_if_fail (GEDIT_IS_WINDOW_ACTIVATABLE (activatable), NULL);
-	g_return_val_if_fail (extension_point != NULL, NULL);
-
-	g_object_get (G_OBJECT (activatable), "window", &window, NULL);
-	model = _gedit_window_get_gear_menu (window);
-	g_object_unref (window);
-
-	n_items = g_menu_model_get_n_items (model);
-
-	for (i = 0; i < n_items; i++)
-	{
-		gchar *id = NULL;
-
-		if (g_menu_model_get_item_attribute (model, i, "id", "s", &id) &&
-		    strcmp (id, extension_point) == 0)
-		{
-			GMenuModel *section;
-
-			section = g_menu_model_get_item_link (model, i, G_MENU_LINK_SECTION);
-			menu = _gedit_menu_extension_new (G_MENU (section));
-		}
-
-		g_free (id);
-	}
-
-	return menu;
-}
-
+/* ex:set ts=8 noet: */
